=================
Burger for Python
=================

|PyPi| |License| |GithubActions| |Docs| |Versions|

The ``burger`` module is a set of simple subroutines used by the ``Burgerlib``
build system.

* Documentation is found at https://pyburger.readthedocs.io

* Doxygen generated documentation is found at https://pyburger.readthedocs.io/en/latest/doxygen

* Python Packing Index (PyPI): https://pypi.python.org/pypi/burger

* Source code and issue tracker: https://github.com/burgerbecky/pyburger

Compatibility
-------------

* Python 2.7.1 or higher
* Python 3.4 or higher

Installation
------------

Type in ``pip install -U burger``. Some platforms may require the ``sudo``
prefix.

Bugs
----

If you find a bug, issue or have a feature request, please submit a bug report
by emailing becky@burgerbecky.com and mention python version, integer
size (32 bit or 64 bit) and what platform was used (Windows / Mac OSX / Linux).

.. |PyPi| image:: https://img.shields.io/pypi/v/burger.svg
    :target: https://pypi.org/project/burger/
    :alt: Pypi Version
.. |License| image:: https://img.shields.io/pypi/l/burger.svg
    :target: https://github.com/burgerbecky/pyburger/blob/master/LICENSE.txt
    :alt: License
.. |GithubActions| image:: https://github.com/burgerbecky/pyburger/actions/workflows/python-build.yml/badge.svg
    :target: https://github.com/burgerbecky/pyburger/actions
    :alt: Github Actions Status
.. |Docs| image:: https://img.shields.io/readthedocs/pyburger.svg
    :target: http://pyburger.readthedocs.io
    :alt: Documentation Status
.. |Versions| image:: https://img.shields.io/pypi/pyversions/burger.svg
    :alt: Supported Python versions
